@@ -342,6 +342,16 @@ class Alicorn:
             else:
                 instance_method = f
 
+            # Build a dictionary out of the invocation_metadata
+            context.metadata = {}
+            for k, v in context.invocation_metadata():
+                if k in context.metadata and isinstance(context.metadata[k], (str, bytes)):
+                    context.metadata[k] = [context.metadata[k], v]
+                elif k in context.metadata:
+                    context.metadata[k].append(v)
+                else:
+                    context.metadata[k] = v
+
             context.alicorn = self._create_context(instance_method)
             # Put the context into the local thread object
             local.context = context
