@@ -3,6 +3,7 @@
 #
 #  There is NO WARRANTY, to the extent permitted by law.
 #
+from typing import Dict, List, Union
 from grpc import ServicerContext
 
 
@@ -21,4 +22,6 @@ class AlicornContext:
 class GrpcContext(ServicerContext):
     """A grpc Context with an alicorn context attached"""
 
+    metadata: Dict[str, Union[List[Union[str, bytes]], str, bytes]]
+
     alicorn: AlicornContext
